@@ -442,6 +442,15 @@ pub fn disp<F: FnOnce(&mut sfmt::Formatter) -> sfmt::Result>(
     util::DisplayableClosureOnce::new(a)
 }
 
+///
+/// Leverage rust's display format system using [`std::cell::RefCell`] under the hood.
+///
+pub fn disp_mut<F: FnMut(&mut sfmt::Formatter) -> sfmt::Result>(
+    a: F,
+) -> util::DisplayableClosureMut<F> {
+    util::DisplayableClosureMut::new(a)
+}
+
 ///
 /// Convert a closure to a object that implements Display
 ///
