@@ -3,6 +3,10 @@ use super::*;
 #[cfg(test)]
 mod tests;
 
+
+
+
+
 ///
 /// Common trait among unix time step generators.
 ///
@@ -41,6 +45,8 @@ impl From<UnixTime> for chrono::DateTime<chrono::Utc> {
     }
 }
 
+
+
 impl UnixTime {
     pub fn datetime<T: TimeZone>(&self, timezone: &T) -> DateTime<T> {
         timezone.timestamp(self.0, 0)
@@ -137,21 +143,7 @@ impl UnixTime {
             let val = self.datetime(timezone);
             use TimestampType::*;
 
-            let m = match val.month() {
-                1 => "Jan",
-                2 => "Feb",
-                3 => "Mar",
-                4 => "Apr",
-                5 => "May",
-                6 => "Jun",
-                7 => "Jul",
-                8 => "Aug",
-                9 => "Sep",
-                10 => "Oct",
-                11 => "Nov",
-                12 => "Dec",
-                _ => unreachable!(),
-            };
+            let m=month_str(val.month());
 
             match info {
                 YR => {
